@@ -44,25 +44,24 @@ class Snowbank():
         self.client.user_data_set({'graph': currFlake})
         return currFlake
 
-    def publish(self, msg):
-        for topic in self.pub_topics:
-            self.client.publish(topic, msg)
+    def publish(self, topic, msg):
+        self.client.publish(topic, msg)
 
     def save(self, graph):
         db_conn = sqlite3.connect(self.db_file)
         save = config.initFromConfig("SAVE_TO_DISK")
         if save == 'yes':
-            graph.save_to_disk(db_conn)
+            graph.save_to_disk(self.db_file)
         db_conn.commit()
 
     def on_connect(self, client, userdata, flags, rc):
         print("Connected with result code "+str(rc))
-        sub_topics = config.initFromConfig('MQTT_SUBSCRIBE_TOPIC').split()
-        for topic in sub_topics:
+        topic = config.initFromConfig('MQTT_TOPIC')
+        if topic is not None:
             client.subscribe(topic, qos=0)
-        pub_topics = config.initFromConfig('MQTT_PUBLISH_TOPIC').split()
-        self.sub_topics = sub_topics
-        self.pub_topics = pub_topics
+        else:
+            print("MQTT topic improperly configured, exiting.")
+            sys.exit()
 
     def on_message(self, client, userdata, msg):
         decoded_msg = zlib.decompress(base64.b64decode(msg.payload.decode('latin-1'))).decode('latin-1')
